==> arrayfire-3.2.1-1-armv7h.pkg.tar.xz: usr/share/ArrayFire/doc/html/group__graphics__func.js <==
var group__graphics__func =
[
    [ "Window", "classaf_1_1Window.htm", [
      [ "Window", "group__gfx__func__window.htm#ga004cf7aac21e18b5b5675f1b635c3734", null ],
      [ "Window", "group__gfx__func__window.htm#gada96f4fe8740ad0bf79388378f217c1f", null ],
      [ "Window", "group__gfx__func__window.htm#ga01089293d764f6706f9873c5f5221a8a", null ],
      [ "Window", "group__gfx__func__window.htm#ga5730679e2a1b3400d35493a41eb8ba92", null ],
      [ "~Window", "group__gfx__func__window.htm#ga254ab61160c1cd5eaa46cc0475bb7a06", null ],
      [ "close", "group__gfx__func__window.htm#ga46143fd6de3be9ab9951f140d3ae8c2f", null ],
      [ "get", "group__gfx__func__window.htm#gafd10b3f27ccd31a1fa3439ff83d1188c", null ],
      [ "grid", "group__gfx__func__window.htm#gaecba84f1690934bbc397e8ac7e141268", null ],
      [ "hist", "group__gfx__func__draw.htm#gafd7d94aa8f5fd37fee0662a4906a38d7", null ],
      [ "image", "group__gfx__func__draw.htm#gaed174450be6db4dfa5ef65b7baccbe57", null ],
      [ "operator()", "classaf_1_1Window.htm#abd5d73da3fbe5e17d4087741e27db1f5", null ],
      [ "plot", "group__gfx__func__draw.htm#ga8e01736df3d805a5488c609e2573818b", null ],
      [ "plot3", "group__gfx__func__draw.htm#ga8e04ec129034e9fe769f3e6b14cd087f", null ],
      [ "setColorMap", "group__gfx__func__window.htm#gacbfc8c0729f789aacefaa78f6421ab14", null ],
      [ "setPos", "group__gfx__func__window.htm#ga91f824616f7dcac3265fff01a55990a9", null ],
      [ "setSize", "group__gfx__func__window.htm#ga2958ea98540a67f41f2b0c34dc9067bd", null ],
      [ "setTitle", "group__gfx__func__window.htm#ga5982bd1cc411e471606311939b3c2721", null ],
      [ "show", "group__gfx__func__window.htm#ga4b148f40a95444d5669406b918ad2f52", null ],
      [ "surface", "group__gfx__func__draw.htm#ga5bc913558053b79956c9d2200471565a", null ],
      [ "surface", "group__gfx__func__draw.htm#ga392b0bb3ae1da66d0fdfb1ef538943e6", null ]
    ] ],
    [ "Rendering Functions", "group__gfx__func__draw.htm", "group__gfx__func__draw" ],
    [ "Window Functions", "group__gfx__func__window.htm", "group__gfx__func__window" ]
];

==> arrayfire-3.3.2-1-armv7h.pkg.tar.xz: usr/share/ArrayFire/doc/html/group__graphics__func.js <==
var group__graphics__func =
[
    [ "Window", "classaf_1_1Window.htm", [
      [ "Window", "group__gfx__func__window.htm#ga004cf7aac21e18b5b5675f1b635c3734", null ],
      [ "Window", "group__gfx__func__window.htm#gada96f4fe8740ad0bf79388378f217c1f", null ],
      [ "Window", "group__gfx__func__window.htm#ga01089293d764f6706f9873c5f5221a8a", null ],
      [ "Window", "group__gfx__func__window.htm#ga5730679e2a1b3400d35493a41eb8ba92", null ],
      [ "~Window", "group__gfx__func__window.htm#ga254ab61160c1cd5eaa46cc0475bb7a06", null ],
      [ "close", "group__gfx__func__window.htm#ga46143fd6de3be9ab9951f140d3ae8c2f", null ],
      [ "get", "group__gfx__func__window.htm#gafd10b3f27ccd31a1fa3439ff83d1188c", null ],
      [ "grid", "group__gfx__func__window.htm#gaecba84f1690934bbc397e8ac7e141268", null ],
      [ "hist", "group__gfx__func__draw.htm#gafd7d94aa8f5fd37fee0662a4906a38d7", null ],
      [ "image", "group__gfx__func__draw.htm#gaed174450be6db4dfa5ef65b7baccbe57", null ],
      [ "operator()", "classaf_1_1Window.htm#abd5d73da3fbe5e17d4087741e27db1f5", null ],
      [ "plot", "group__gfx__func__draw.htm#ga8e01736df3d805a5488c609e2573818b", null ],
      [ "plot3", "group__gfx__func__draw.htm#ga8e04ec129034e9fe769f3e6b14cd087f", null ],
      [ "scatter", "group__gfx__func__draw.htm#ga73406db589e5090c051baae0af175df9", null ],
      [ "scatter3", "group__gfx__func__draw.htm#ga3bbfbe1b60741a259d2146b3ab50ace3", null ],
      [ "setColorMap", "group__gfx__func__window.htm#gacbfc8c0729f789aacefaa78f6421ab14", null ],
      [ "setPos", "group__gfx__func__window.htm#ga91f824616f7dcac3265fff01a55990a9", null ],
      [ "setSize", "group__gfx__func__window.htm#ga2958ea98540a67f41f2b0c34dc9067bd", null ],
      [ "setTitle", "group__gfx__func__window.htm#ga5982bd1cc411e471606311939b3c2721", null ],
      [ "setVisibility", "group__gfx__func__window.htm#ga9ff8d74c894cf172a03900f61887524d", null ],
      [ "show", "group__gfx__func__window.htm#ga4b148f40a95444d5669406b918ad2f52", null ],
      [ "surface", "group__gfx__func__draw.htm#ga1cdb8c3205d70d8feaddd8c30245393f", null ],
      [ "surface", "group__gfx__func__draw.htm#ga2d09aa253b391ce82104352b743bb18c", null ]
    ] ],
    [ "Rendering Functions", "group__gfx__func__draw.htm", "group__gfx__func__draw" ],
    [ "Window Functions", "group__gfx__func__window.htm", "group__gfx__func__window" ]
];
